@@ -22,9 +22,9 @@ pip install types-Flask
 <https://packaging.python.org/en/latest/tutorials/packaging-projects/>
 
 ### Deploy to pip
+# update version number in setup.py first.
 cd ~/bin/app/python-service
 rm dist/ -rf
-# update version number in setup.py first.
 python3 setup.py sdist
 twine upload dist/*
 pip3 install jiesu-python-service -U
@@ -154,7 +154,7 @@ class HttpRequestHandler(BaseHTTPRequestHandler):
             self.log.exception(ex)
 
     def do_POST(self):
-        self.log.info("Received POST request - {}", self.path)
+        self.log.info("Received POST request " + self.path)
         try:
             self.handler.post()
         except socket.error:
@@ -163,7 +163,7 @@ class HttpRequestHandler(BaseHTTPRequestHandler):
             self.log.exception(ex)
 
     def do_DELETE(self):
-        self.log.info("Received DELETE request - {}", self.path)
+        self.log.info("Received DELETE request " + self.path)
         try:
             self.handler.delete()
         except socket.error:
@@ -172,7 +172,7 @@ class HttpRequestHandler(BaseHTTPRequestHandler):
             self.log.exception(ex)
 
     def do_PUT(self):
-        self.log.info("Received PUT request - {}", self.path)
+        self.log.info("Received PUT request " + self.path)
         try:
             self.handler.put()
         except socket.error:
